@@ -148,12 +148,14 @@ fn output_colored_path(
     let size_width = byte_format.width();
     let path = path.as_ref().display();
 
-    let errors = (num_errors != 0)
-        .then(|| {
-            let plural_s = if num_errors > 1 { "s" } else { "" };
-            format!("  <{num_errors} IO Error{plural_s}>")
-        })
-        .unwrap_or_default();
+    let errors = if num_errors != 0 {
+        format!(
+            "  <{num_errors} IO Error{plural_s}>",
+            plural_s = if num_errors > 1 { "s" } else { "" }
+        )
+    } else {
+        "".into()
+    };
 
     if let Some(color) = path_color {
         writeln!(out, "{size:>size_width$} {}{errors}", path.color(color))
